import { Request, Response, Router } from "express";
import multer from "multer";
import path from "path";
import fs from "fs";

const router = Router();

// Configure Multer for file storage
const storage = multer.diskStorage({
  destination: (req, file, cb) => {
    const uploadPath = path.join(__dirname, "data", "uploads");
    if (!fs.existsSync(uploadPath)) {
      fs.mkdirSync(uploadPath, { recursive: true });
    }
    cb(null, uploadPath);
  },
  filename: (req, file, cb) => {
    const uniqueSuffix = Date.now() + "-" + Math.round(Math.random() * 1e9);
    const extension = path.extname(file.originalname);
    cb(null, `${file.fieldname}-${uniqueSuffix}${extension}`);
  },
});

const upload = multer({ storage });

// File upload endpoint
router.post(
  "/upload",
  upload.single("file"),
  async (req: Request, res: Response) => {
    try {
      if (!req.file) {
        return res.status(400).json({ message: "No file uploaded" });
      }

      const { originalname, path: filePath, mimetype } = req.file;

      // // Save file metadata to the database
      // const fileRecord = await prisma.file.create({
      //   data: {
      //     originalName: originalname,
      //     filePath: filePath,
      //     mimeType: mimetype,
      //   },
      // });

      // Construct the file URL
     // console.log("Uploaded File Path", filePath);
      const fileUrl = `${req.protocol}://${req.get("host")}/uploads/${path.basename(filePath)}`;

      res.status(200).json({ message: "File uploaded successfully", fileUrl , filePath });
    } catch (error) {
     // console.error("Error uploading file:", error);
      res.status(500).json({ message: "File upload failed", error });
    }
  }
);

export default router;
